@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'				=> 'Fus horari dels visitants',
 	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Fus horari utilitzat per mostrar hores als usuaris que no han iniciat sessió (visitants, robots). Els usuaris que han iniciat sessió decideixen el seu fus horari durant el procediment de registre i poden canviar-lo al Tauler de control de l’usuari.',
 	'WARNINGS_EXPIRE'				=> 'Durada dels advertiments',
-	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Nombre de dies que han de passar abans que un advertiment venci automàticament del registre d’un usuari.',
+	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Nombre de dies que han de passar abans que un advertiment venci automàticament del registre d’un usuari. Utilitzeu el valor 0 per fer que els advertiments siguin permanents.',
 ));
 
 // Board Features
@@ -174,7 +174,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'					=> 'Nombre màxim d’enllaços per entrada',
 	'MAX_POST_URLS_EXPLAIN'			=> 'Nombre màxim d’URL en una entrada. Introduïu un 0 per a enllaços il·limitats.',
 	'MIN_CHAR_LIMIT'				=> 'Nombre mínim de caràcters per entrada/missatge',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'El nombre mínim de caràcters que cal que un usuari introdueixi al text d’una entrada o missatge privat.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'El nombre mínim de caràcters que cal que un usuari introdueixi al text d’una entrada o missatge privat. El valor mínim per aquesta configuració es 1.',
 	'POSTING'						=> 'Publicació',
 	'POSTS_PER_PAGE'				=> 'Entrades per pàgina',
 	'QUOTE_DEPTH_LIMIT'				=> 'Profunditat màxima d’incrustació per citacions',
