@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'				=> 'Heu d’especificar un assumpte quan redacteu un missatge nou.',
 	'ENABLED'							=> 'Habilitat',
 	'ENCLOSURE'							=> 'Document adjunt',
+	'ENTER_USERNAME'					=> 'Introduïu el nom d’usuari',
 	'ERR_CHANGING_DIRECTORY'			=> 'No s’ha pogut canviar el directori.',
 	'ERR_CONNECTING_SERVER'				=> 'S’ha produït un error en connectar amb el servidor.',
 	'ERR_JAB_AUTH'						=> 'No se us ha pogut autoritzar al servidor Jabber.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'		=> 'Si us plau feu clic aquí per veure les regles del fòrum',
 	'FROM'					=> 'des de',
 	'FSOCK_DISABLED'		=> 'No s’ha pogut completar l’operació perquè s’ha inhabilitat la funció <var>fsockopen</var> o bé no s’ha trobat el servidor consultat.',
+	'FSOCK_TIMEOUT'			=> 'S’ha excedit el temps d’espera mentre es llegia el flux de dades de la xarxa.',
 
 	'FTP_FSOCK_HOST'				=> 'Servidor FTP',
 	'FTP_FSOCK_HOST_EXPLAIN'		=> 'Servidor FTP utilitzat per connectar-vos al vostre lloc web.',
@@ -652,6 +654,10 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'			=> '<strong>%d</strong> missatges no llegits',
 	'UNREAD_POST'			=> 'Entrada no llegida',
 	'UNREAD_POSTS'			=> 'Entrades no llegides',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Esteu segur que voleu cancel·lar la subscripció a aquest fòrum?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Esteu segur que voleu cancel·lar la subscripció al fòrum “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Esteu segur que voleu cancel·lar la subscripció a aquest tema?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Esteu segur que voleu cancel·lar la subscripció al tema “%s”?',
 	'UNWATCHED_FORUMS'		    => 'Ja no esteu subscrit als fòrums seleccionats.',
 	'UNWATCHED_TOPICS'		    => 'Ja no esteu subscrit als temes seleccionats.',
 	'UNWATCHED_FORUMS_TOPICS'	=> 'Ja no esteu subscrit als elements seleccionats.',
@@ -700,6 +706,10 @@ $lang = array_merge($lang, array(
 
 	'WARNINGS'			=> 'Advertiments',
 	'WARN_USER'			=> 'Adverteix l’usuari',
+	'WATCH_FORUM_CONFIRM'	=> 'Esteu segur que us voleu subscriure a aquest fòrum?',
+	'WATCH_FORUM_DETAILED'	=> 'Esteu segur que us voleu subscriure al fòrum “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Esteu segur que us voleu subscriure a aquest tema?',
+	'WATCH_TOPIC_DETAILED'	=> 'Esteu segur que us voleu subscriure al tema “%s”?',
 	'WELCOME_SUBJECT'	=> 'Benvingut als fòrums %s',
 	'WEBSITE'			=> 'Lloc web',
 	'WHOIS'				=> 'Whois',
