@@ -138,6 +138,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'Imatge actual',
 	'CURRENT_PASSWORD'			=> 'Contrasenya actual',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Cal que confirmeu la vostra contrasenya quan la canvieu, o canvieu la vostra adreça electrònica o nom d’usuari.',
+	'CUR_PASSWORD_EMPTY'		=> 'No heu introduït la vostra contrasenya actual.',
 	'CUR_PASSWORD_ERROR'		=> 'La contrasenya que heu introduït no és correcta.',
 	'CUSTOM_DATEFORMAT'			=> 'Personalitzada…',
 
@@ -268,9 +269,11 @@ $lang = array_merge($lang, array(
 	'MOVE_TO_FOLDER'				=> 'Desplaça’l a la carpeta',
 	'MOVE_UP'						=> 'Puja',
 
-	'NEW_EMAIL_ERROR'				=> 'Les adreces alectròniques que heu introduït no coincideixen.',
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'No heu introduït l’adreça electrònica de confirmació.',
+	'NEW_EMAIL_ERROR'				=> 'Les adreces electròniques que heu introduït no coincideixen.',
 	'NEW_FOLDER_NAME'				=> 'Nom de la carpeta nova',
 	'NEW_PASSWORD'					=> 'Contrasenya nova',
+	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'No heu introduït la contrasenya de confirmació.',
 	'NEW_PASSWORD_ERROR'			=> 'Les contrasenyes que heu heu introduït no coincideixen.',
 	'NOTIFY_METHOD'					=> 'Mètode de notificació',
 	'NOTIFY_METHOD_BOTH'			=> 'Ambdós',
